pub fn is_html(input: &str) -> boolExpand description
Determine if a given string contains HTML
This function is parses the full string into HTML and checks if the input contained any HTML syntax.
Note
This function will return positively for strings that contain invalid HTML syntax like
<g> and even Vec::<u8>::new().